@@ -1,11 +1,12 @@
 from functools import wraps
+from typing import Union, Tuple
+
 from bools.log import Logger
 from bools.datetime import Datetime
-from typing import Union, Tuple
 
 
 def catch(_func=None, *, exception: Union[Tuple[type(Exception), ...], type(Exception)] = Exception,
-          except_func=print, except_return=None, log=''):
+          except_func=None, except_return=None, log='', print_traceback=True):
     def decorator(func):
         @wraps(func)
         def wrapper(*args, **kwargs):
@@ -13,10 +14,14 @@ def catch(_func=None, *, exception: Union[Tuple[type(Exception), ...], type(Exce
                 return func(*args, **kwargs)
             except exception:
                 import traceback
-                except_func()
-                Logger.error(log)
-                print(traceback.print_exc())
-                return except_return
+                if except_func is not None:
+                    except_func()
+                if log:
+                    Logger.error(log)
+                if print_traceback:
+                    print(traceback.print_exc())
+                if except_return is not None:
+                    return except_return
 
         return wrapper
 
@@ -40,3 +45,23 @@ def timeit(_func=None, *, count=3, return_costs=False):
         return wrapper
 
     return decorator(_func) if _func else decorator
+
+
+def parallel(func=None, count: int = None):
+    setattr(_outer_func, _FUNC, func)
+
+    def inner(data: list):
+        from multiprocessing import Pool
+        with Pool(count) as p:
+            result = p.map(_outer_func, data)
+        return result
+
+    return inner
+
+
+_FUNC = 'func'
+
+
+def _outer_func(*args, **kwargs):
+    func = getattr(_outer_func, _FUNC)
+    return func(*args, **kwargs) if func.__code__.co_argcount else func()
