@@ -20,12 +20,13 @@ class ElasticSearchTest(unittest.TestCase):
         print(data.shape)
         # print(data.head())
         """
-        self.es = ElasticSearch(host='localhost', patch_pandas=True)
+        self.es = ElasticSearch(base_url='http://elastic:cb1998827@localhost:9200', patch_pandas=True)
         # self.es.delete('test*')
 
     @classmethod
     def test_init(cls):
-        ElasticSearch()
+        # ElasticSearch()
+        # print(ElasticSearch(base_url='http://elastic:cb1998827@localhost:9200').version)
         # ElasticSearch(host='http://10.0.80.167', patch_pandas=False)
         # ElasticSearch(user='elastic', password='cb1998827', patch_pandas=True)
         pass
